@@ -15,6 +15,7 @@ from _pytest import nodes
 from _pytest.config import directory_arg
 from _pytest.config import hookimpl
 from _pytest.config import UsageError
+from _pytest.fixtures import FixtureManager
 from _pytest.outcomes import exit
 from _pytest.runner import collect_one_node
 from _pytest.runner import SetupState
@@ -366,9 +367,9 @@ class Failed(Exception):
 
 @attr.s
 class _bestrelpath_cache(dict):
-    path = attr.ib()
+    path = attr.ib(type=py.path.local)
 
-    def __missing__(self, path: str) -> str:
+    def __missing__(self, path: py.path.local) -> str:
         r = self.path.bestrelpath(path)  # type: str
         self[path] = r
         return r
@@ -377,7 +378,10 @@ class _bestrelpath_cache(dict):
 class Session(nodes.FSCollector):
     Interrupted = Interrupted
     Failed = Failed
+    # Set on the session by runner.pytest_sessionstart.
     _setupstate = None  # type: SetupState
+    # Set on the session by fixtures.pytest_sessionstart.
+    _fixturemanager = None  # type: FixtureManager
 
     def __init__(self, config):
         nodes.FSCollector.__init__(
@@ -395,7 +399,7 @@ class Session(nodes.FSCollector):
         self._node_cache = {}
         self._bestrelpathcache = _bestrelpath_cache(
             config.rootdir
-        )  # type: Dict[str, str]
+        )  # type: Dict[py.path.local, str]
         # Dirnames of pkgs with dunder-init files.
         self._pkg_roots = {}
 
@@ -410,7 +414,7 @@ class Session(nodes.FSCollector):
             self.testscollected,
         )
 
-    def _node_location_to_relpath(self, node_path: str) -> str:
+    def _node_location_to_relpath(self, node_path: py.path.local) -> str:
         # bestrelpath is a quite slow function
         return self._bestrelpathcache[node_path]
 
